@@ -7,7 +7,7 @@ use Exporter 'import';
 use ExtUtils::MakeMaker;
 use XS::Install::Payload;
 
-our $VERSION = '1.0.9';
+our $VERSION = '1.0.10';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile makemaker_args/;
@@ -121,6 +121,9 @@ sub makemaker_args {
         $cppv = 11 if $cppv < 11;
         _string_merge($params{CCFLAGS}, "-std=c++$cppv");
         
+        # prevent C++ from compile errors on perls <= 5.18, as perl had buggy <perl.h> prior to 5.20
+        _string_merge($params{CCFLAGS}, "-Wno-reserved-user-defined-literal -Wno-literal-suffix -Wno-unknown-warning-option") if $^V < v5.20;
+         
         _check_sjlj();
     }
     
